# Tarts LSP Client

Tarts is a client library for managing language server requests & responses. Tarts is the featured lsp integration used in Biscuit code editor.

## Testing
Tests of Tarts use **pytest**. To run tests, first install the langservers needed, check [workflow file](.github/workflows/test.yml) for further info.

## Acknowledgements
Tarts is an up-to-date fork of [*sansio_lsp_client*](https://github.com/PurpleMyst/sansio-lsp-client) by Purple Myst. 
